@@ -169,7 +169,7 @@ doc <- read_docx() %>%
   body_add_par("centered text", style = "centered") %>%
   slip_in_text(". How are you", style = "strong") %>%
   body_bookmark("text_to_replace") %>%
-  body_replace_at("text_to_replace", "not left aligned")
+  body_replace_text_at_bkm("text_to_replace", "not left aligned")
 
 ## ----results='hide'------------------------------------------------------
 doc <- read_docx() %>%
@@ -197,17 +197,69 @@ office_doc_link( url = paste0( "https://davidgohel.github.io/officer/articles/",
 
 ## ------------------------------------------------------------------------
 str1 <- "Lorem ipsum dolor sit amet, consectetur adipiscing elit. " %>% 
-  rep(30) %>% paste(collapse = "")
+  rep(5) %>% paste(collapse = "")
 str2 <- "Aenean venenatis varius elit et fermentum vivamus vehicula. " %>% 
-  rep(30) %>% paste(collapse = "")
+  rep(5) %>% paste(collapse = "")
 
 my_doc <- read_docx()  %>% 
-  slip_in_text(str = str1, style = "strong") %>% 
+  body_add_par(value = str1, style = "centered") %>% 
+  body_end_section_continuous() %>% 
   body_add_par(value = str2, style = "centered") %>% 
-  break_column_before() %>% 
-  body_end_section(continuous = TRUE, 
-                   colwidths = c(.6, .4), space = .05, sep = FALSE) %>%
-  body_add_par(value = str3, style = "Normal") 
+  body_end_section_landscape() 
+print(my_doc, target = "assets/docx/landscape_section.docx")
+
+## ----echo=FALSE----------------------------------------------------------
+office_doc_link( url = paste0( "https://davidgohel.github.io/officer/articles/", "assets/docx/landscape_section.docx" ) )
+
+## ------------------------------------------------------------------------
+my_doc <- read_docx()  %>% 
+  body_end_section_continuous() %>% 
+  body_add_par(value = str1, style = "centered") %>% 
+  body_add_par(value = str2, style = "centered") %>% 
+  slip_in_column_break() %>%
+  body_add_par(value = str2, style = "centered") %>% 
+  body_end_section_columns(widths = c(2,2), sep = TRUE, space = 1) 
+print(my_doc, target = "assets/docx/columns_section.docx")
+
+## ----echo=FALSE----------------------------------------------------------
+office_doc_link( url = paste0( "https://davidgohel.github.io/officer/articles/", "assets/docx/columns_section.docx" ) )
+
+## ------------------------------------------------------------------------
+my_doc <- read_docx()  %>% 
+  body_end_section_continuous() %>% 
+  body_add_par(value = str1, style = "Normal") %>% 
+  body_add_par(value = str2, style = "Normal") %>% 
+  body_end_section_columns_landscape(widths = c(3,3), sep = TRUE, space = 1) 
+print(my_doc, target = "assets/docx/columns_landscape_section.docx")
+
+## ----echo=FALSE----------------------------------------------------------
+office_doc_link( url = paste0( "https://davidgohel.github.io/officer/articles/", "assets/docx/columns_landscape_section.docx" ) )
+
+## ------------------------------------------------------------------------
+my_doc <- read_docx()  %>% 
+  body_add_par(value = "Default section", style = "heading 1") %>% 
+  body_add_par(value = str1, style = "centered") %>% 
+  body_add_par(value = str2, style = "centered") %>% 
+
+  body_end_section_continuous() %>% 
+  body_add_par(value = "Landscape section", style = "heading 1") %>% 
+  body_add_par(value = str1, style = "centered") %>% 
+  body_add_par(value = str2, style = "centered") %>% 
+  body_end_section_landscape() %>% 
+  
+  body_add_par(value = "Columns", style = "heading 1") %>% 
+  body_end_section_continuous() %>% 
+  body_add_par(value = str1, style = "centered") %>% 
+  body_add_par(value = str2, style = "centered") %>% 
+  slip_in_column_break() %>%
+  body_add_par(value = str1, style = "centered") %>% 
+  body_end_section_columns(widths = c(2,2), sep = TRUE, space = 1) %>% 
+
+  body_add_par(value = str1, style = "Normal") %>% 
+  body_add_par(value = str2, style = "Normal") %>% 
+  slip_in_column_break() %>%
+  body_end_section_columns_landscape(widths = c(3,3), sep = TRUE, space = 1)
+
 print(my_doc, target = "assets/docx/section.docx")
 
 ## ----echo=FALSE----------------------------------------------------------
