@@ -9,14 +9,14 @@ test_that("defaul template", {
 test_that("console printing", {
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world")
+  x <- ph_with(x, "Hello world", location = ph_location_type(type = "body"))
   expect_output(print(x), "pptx document with 1 ")
 })
 
 test_that("check extention and print document", {
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world")
+  x <- ph_with(x, "Hello world", location = ph_location_type(type = "body"))
   print(x, target = "print.pptx")
   expect_true( file.exists("print.pptx") )
 
@@ -27,12 +27,12 @@ test_that("check extention and print document", {
 test_that("check template", {
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world")
+  x <- ph_with(x, "Hello world", location = ph_location_type(type = "body"))
   print(x, target = "template.pptx")
 
   expect_silent(x <- read_pptx(path = "template.pptx"))
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world again")
+  x <- ph_with(x, "Hello world again", location = ph_location_type(type = "body"))
   print(x, target = "example.pptx")
 
   expect_equal(length(x), 2)
@@ -43,11 +43,11 @@ test_that("check template", {
 test_that("slide remove", {
   x <- read_pptx() %>%
     add_slide("Title and Content", "Office Theme") %>%
-    ph_with_text(type = "body", str = "Hello world 1") %>%
+    ph_with("Hello world 1", location = ph_location_type(type = "body")) %>%
     add_slide("Title and Content", "Office Theme") %>%
-    ph_with_text(type = "body", str = "Hello world 2") %>%
+    ph_with("Hello world 2", location = ph_location_type(type = "body")) %>%
     add_slide("Title and Content", "Office Theme") %>%
-    ph_with_text(type = "body", str = "Hello world 3")
+    ph_with("Hello world 3", location = ph_location_type(type = "body"))
   print(x, target = "template.pptx")
 
   x <- read_pptx(path = "template.pptx")
@@ -65,11 +65,11 @@ test_that("slide remove", {
 test_that("ph remove", {
   x <- read_pptx() %>%
     add_slide("Title and Content", "Office Theme") %>%
-    ph_with_text(type = "body", str = "Hello world 1") %>%
+    ph_with("Hello world 1", location = ph_location_type(type = "body")) %>%
     add_slide("Title and Content", "Office Theme") %>%
-    ph_with_text(type = "body", str = "Hello world 2") %>%
+    ph_with("Hello world 2", location = ph_location_type(type = "body")) %>%
     add_slide("Title and Content", "Office Theme") %>%
-    ph_with_text(type = "body", str = "Hello world 3")
+    ph_with("Hello world 3", location = ph_location_type(type = "body"))
   print(x, target = "template.pptx")
 
   x <- read_pptx(path = "template.pptx")
@@ -83,7 +83,7 @@ test_that("cursor is incremented as expected", {
   x <- read_pptx()
   for(i in 1:11){
     x <- add_slide(x, "Title Slide", "Office Theme")
-    x <- ph_with_text(x, i, type = "ctrTitle")
+    x <- ph_with(x, i, location = ph_location_type(type = "ctrTitle"))
   }
   expect_equal(nrow( slide_summary(x, 11) ), 1 )
   expect_equal(x$slide$get_slide(11)$name(), "slide11.xml" )
