@@ -6,11 +6,11 @@ test_that("check errors", {
 
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world 1")
+  x <- ph_with(x, "Hello world 1", location = ph_location_type(type = "body"))
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world 2")
+  x <- ph_with(x, "Hello world 2", location = ph_location_type(type = "body"))
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world 3")
+  x <- ph_with(x, "Hello world 3", location = ph_location_type(type = "body"))
 
   x <- x %>% on_slide(index = 1)
   sm <- slide_summary(x)
