@@ -3,11 +3,11 @@ context("checks selections for pptx")
 test_that("check slide selection", {
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world 1")
+  x <- ph_with(x, "Hello world 1", location = ph_location_type(type = "body"))
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world 2")
+  x <- ph_with(x, "Hello world 2", location = ph_location_type(type = "body"))
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world 3")
+  x <- ph_with(x, "Hello world 3", location = ph_location_type(type = "body"))
 
   x <-  x %>% on_slide(index = 1)
   sm <- slide_summary(x)
@@ -30,11 +30,11 @@ test_that("check errors", {
   expect_error(on_slide(x, index = 1), "presentation contains no slide")
 
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world")
-  x <- ph_with_text(x, type = "title", str = "my title")
+  x <- ph_with(x, "Hello world", location = ph_location_type(type = "body"))
+  x <- ph_with(x, "my title", location = ph_location_type(type = "title"))
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with_text(x, type = "body", str = "Hello world")
-  x <- ph_with_text(x, type = "title", str = "my title 2")
+  x <- ph_with(x, "Hello world", location = ph_location_type(type = "body"))
+  x <- ph_with(x, "my title 2", location = ph_location_type(type = "title"))
 
   expect_error(on_slide(x, index = 3), "unvalid index 3")
   expect_error(remove_slide(x, index = 3), "unvalid index 3")
@@ -46,7 +46,7 @@ test_that("get shape id", {
 
   doc <- read_pptx() %>%
     add_slide("Title and Content", "Office Theme") %>%
-    ph_with_text(type = "body", str = "hello")
+    ph_with("hello", location = ph_location_type(type = "body"))
   expect_equal(officer:::get_shape_id(doc, type = "body", id_chr = "2"), 1)
   expect_equal(officer:::get_shape_id(doc, type = "body"), 1)
   expect_equal(officer:::get_shape_id(doc, id_chr = "2"), 1)
